@@ -3,8 +3,10 @@ import requests
 from . import PureError
 
 from . import FA_2_8
+from . import FA_2_10
 from . import FA_2_6
 from . import FA_2_4
+from . import FA_2_9
 from . import FA_2_1
 from . import FA_2_3
 from . import FA_2_5
@@ -14,8 +16,10 @@ from . import FA_2_7
 
 fa_modules = {
     '2.8': FA_2_8,
+    '2.10': FA_2_10,
     '2.6': FA_2_6,
     '2.4': FA_2_4,
+    '2.9': FA_2_9,
     '2.1': FA_2_1,
     '2.3': FA_2_3,
     '2.5': FA_2_5,
